@@ -9,6 +9,7 @@ use Mojo::Pg::PubSub;
 use Mojo::URL;
 use Scalar::Util 'weaken';
 
+has [qw(auto_migrate search_path)];
 has dsn             => 'dbi:Pg:';
 has max_connections => 5;
 has migrations      => sub {
@@ -25,9 +26,8 @@ has pubsub => sub {
   weaken $pubsub->{pg};
   return $pubsub;
 };
-has 'search_path';
 
-our $VERSION = '2.16';
+our $VERSION = '2.18';
 
 sub db {
   my $self = shift;
@@ -82,6 +82,8 @@ sub _dequeue {
     my $search_path = join ', ', map { $dbh->quote_identifier($_) } @$path;
     $dbh->do("set search_path to $search_path");
   }
+  ++$self->{migrated} and $self->migrations->migrate
+    if $self->auto_migrate && !$self->{migrated};
   $self->emit(connection => $dbh);
 
   return $dbh;
@@ -171,7 +173,7 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
 L<Mojo::Pg> is a tiny wrapper around L<DBD::Pg> that makes
 L<PostgreSQL|http://www.postgresql.org> a lot of fun to use with the
-L<Mojolicious|http://mojolicio.us> real-time web framework.
+L<Mojolicious|http://mojolicious.org> real-time web framework.
 
 Database and statement handles are cached automatically, so they can be reused
 transparently to increase performance. And you can handle connection timeouts
@@ -231,6 +233,14 @@ Emitted when a new database connection has been established.
 
 L<Mojo::Pg> implements the following attributes.
 
+=head2 auto_migrate
+
+  my $bool = $pg->auto_migrate;
+  $pg      = $pg->auto_migrate($bool);
+
+Automatically migrate to the latest database schema with L</"migrations">, as
+soon as the first database connection has been established.
+
 =head2 dsn
 
   my $dsn = $pg->dsn;
@@ -403,7 +413,7 @@ Hernan Lopes
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015, Sebastian Riedel.
+Copyright (C) 2014-2016, Sebastian Riedel.
 
 This program is free software, you can redistribute it and/or modify it under
 the terms of the Artistic License version 2.0.
@@ -411,6 +421,6 @@ the terms of the Artistic License version 2.0.
 =head1 SEE ALSO
 
 L<https://github.com/kraih/mojo-pg>, L<Mojolicious::Guides>,
-L<http://mojolicio.us>.
+L<http://mojolicious.org>.
 
 =cut
